@@ -54,27 +54,27 @@
 <context>
     <name>ContactIDField</name>
     <message>
-        <location filename="../src/ui/qml/ContactIDField.qml" line="40"/>
+        <location filename="../src/ui/qml/ContactIDField.qml" line="41"/>
         <source>&lt;b&gt;%1&lt;/b&gt; is already your contact</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; ya es su contacto</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/ContactIDField.qml" line="42"/>
+        <location filename="../src/ui/qml/ContactIDField.qml" line="43"/>
         <source>You can&apos;t add yourself as a contact</source>
         <translation>No puede añadirse a usted mismo como un contacto</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/ContactIDField.qml" line="44"/>
+        <location filename="../src/ui/qml/ContactIDField.qml" line="45"/>
         <source>Enter an ID starting with &lt;b&gt;ricochet:&lt;/b&gt;</source>
         <translation>Introduzca un ID comience con &lt;b&gt;ricochet:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/ContactIDField.qml" line="80"/>
+        <location filename="../src/ui/qml/ContactIDField.qml" line="81"/>
         <source>Copied to clipboard</source>
         <translation>Copiado al portapapeles</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/ContactIDField.qml" line="92"/>
+        <location filename="../src/ui/qml/ContactIDField.qml" line="93"/>
         <source>Copy</source>
         <translation>Copiar</translation>
     </message>
@@ -210,37 +210,45 @@
 <context>
     <name>GeneralPreferences</name>
     <message>
-        <location filename="../src/ui/qml/GeneralPreferences.qml" line="12"/>
+        <location filename="../src/ui/qml/GeneralPreferences.qml" line="13"/>
         <source>Use a single window for conversations</source>
         <translation>Usar una única ventana para conversaciones</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/GeneralPreferences.qml" line="20"/>
+        <location filename="../src/ui/qml/GeneralPreferences.qml" line="21"/>
         <source>Open links in default browser without prompting</source>
         <translation>Abrir enlaces en el navegador predeterminado sin pedir confirmación</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/GeneralPreferences.qml" line="28"/>
+        <location filename="../src/ui/qml/GeneralPreferences.qml" line="29"/>
         <source>Play audio notifications</source>
         <translation>Reproducir notificaciones de audio</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/GeneralPreferences.qml" line="37"/>
+        <location filename="../src/ui/qml/GeneralPreferences.qml" line="38"/>
         <source>Volume</source>
         <translation>Volumen</translation>
     </message>
+    <message>
+        <location filename="../src/ui/qml/GeneralPreferences.qml" line="53"/>
+        <source>Language</source>
+        <translation type="unfinished">Idioma</translation>
+    </message>
+    <message>
+        <location filename="../src/ui/qml/GeneralPreferences.qml" line="76"/>
+        <source>Restart Ricochet to apply changes</source>
+        <translation type="unfinished">Reiniciar Ricochet para aplicar los cambios</translation>
+    </message>
 </context>
 <context>
     <name>LanguagePreferences</name>
     <message>
-        <location filename="../src/ui/qml/LanguagePreferences.qml" line="22"/>
         <source>Select Language</source>
-        <translation>Seleccionar idioma</translation>
+        <translation type="vanished">Seleccionar idioma</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/LanguagePreferences.qml" line="52"/>
         <source>Restart Ricochet to apply changes</source>
-        <translation>Reiniciar Ricochet para aplicar los cambios</translation>
+        <translation type="vanished">Reiniciar Ricochet para aplicar los cambios</translation>
     </message>
 </context>
 <context>
@@ -254,7 +262,7 @@
 <context>
     <name>Main</name>
     <message>
-        <location filename="../src/main.cpp" line="73"/>
+        <location filename="../src/main.cpp" line="81"/>
         <source>Ricochet Error</source>
         <translation>Error de Ricochet</translation>
     </message>
@@ -436,22 +444,21 @@
         <translation>General</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
         <source>Language</source>
-        <translation>Idioma</translation>
+        <translation type="vanished">Idioma</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
+        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
         <source>Contacts</source>
         <translation>Contactos</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
+        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
         <source>Tor</source>
         <translation>Tor</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/PreferencesDialog.qml" line="61"/>
+        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
@@ -509,84 +516,84 @@
 <context>
     <name>TorConfigurationPage</name>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="72"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="73"/>
         <source>Does this computer need a proxy to access the internet?</source>
         <translation>¿Este equipo necesita un proxy para acceder a Internet?</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="84"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="85"/>
         <source>Proxy type:</source>
         <translation>Tipo de proxy:</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="89"/>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="91"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="90"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="92"/>
         <source>None</source>
         <translation>Ninguno</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="106"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="107"/>
         <source>Address:</source>
         <translation>Dirección:</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="115"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="116"/>
         <source>IP address or hostname</source>
         <translation>Dirección IP o nombre del equipo</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="118"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="119"/>
         <source>Port:</source>
         <translation>Puerto:</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="129"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="130"/>
         <source>Username:</source>
         <translation>Nombre de usuario:</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="139"/>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="149"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="140"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="150"/>
         <source>Optional</source>
         <translation>Opcional</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="142"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="143"/>
         <source>Password:</source>
         <translation>Contraseña:</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="159"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="160"/>
         <source>Does this computer&apos;s Internet connection go through a firewall that only allows connections to certain ports?</source>
         <translation>¿La conexión a Internet de este equipo va a través de un cortafuegos (firewall) que sólo permite conexiones a ciertos puertos?</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="170"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="171"/>
         <source>Allowed ports:</source>
         <translation>Puertos permitidos:</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="177"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="178"/>
         <source>Example: 80,443</source>
         <translation>Ejemplo: 80,443</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="188"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="189"/>
         <source>If this computer&apos;s Internet connection is censored, you will need to obtain and use bridge relays.</source>
         <translation>Si la conexión a Internet de este equipo está bajo censura, necesitará obtener y usar repetidores puente (bridge relays).</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="197"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="198"/>
         <source>Enter one or more bridge relays (one per line):</source>
         <translation>Introduzca uno o más repetidores puente (uno por línea):</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="212"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="213"/>
         <source>Back</source>
         <translation>Atrás</translation>
     </message>
     <message>
-        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="219"/>
+        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="220"/>
         <source>Connect</source>
         <translation>Conectar</translation>
     </message>
